pub struct SpendPrefixInTransactionV5 {
pub cv: ValueCommitment,
pub nullifier: Nullifier,
pub rk: ValidatingKey,
}Expand description
The serialization prefix fields of a Spend in Transaction V5.
In V5 transactions, spends are split into multiple arrays, so the prefix,
proof, and signature must be serialised and deserialized separately.
Serialized as SpendDescriptionV5 in protocol specification 7.3.
Fields
cv: ValueCommitmentA value commitment to the value of the input note.
nullifier: NullifierThe nullifier of the input note.
rk: ValidatingKeyThe randomized public key for spend_auth_sig.